define(
//begin v1.x content
({
	'bold': '粗體',
	'copy': '複製',
	'cut': '剪下',
	'delete': '刪除',
	'indent': '縮排',
	'insertHorizontalRule': '水平尺規',
	'insertOrderedList': '編號清單',
	'insertUnorderedList': '項目符號清單',
	'italic': '斜體',
	'justifyCenter': '置中對齊',
	'justifyFull': '對齊',
	'justifyLeft': '靠左對齊',
	'justifyRight': '靠右對齊',
	'outdent': '凸排',
	'paste': '貼上',
	'redo': '重做',
	'removeFormat': '移除格式',
	'selectAll': '全選',
	'strikethrough': '刪除線',
	'subscript': '下標',
	'superscript': '上標',
	'underline': '底線',
	'undo': '復原',
	'unlink': '移除鏈結',
	'createLink': '建立鏈結',
	'toggleDir': '切換方向',
	'insertImage': '插入影像',
	'insertTable': '插入/編輯表格',
	'toggleTableBorder': '切換表格邊框',
	'deleteTable': '刪除表格',
	'tableProp': '表格內容',
	'htmlToggle': 'HTML 原始檔',
	'foreColor': '前景顏色',
	'hiliteColor': '背景顏色',
	'plainFormatBlock': '段落樣式',
	'formatBlock': '段落樣式',
	'fontSize': '字型大小',
	'fontName': '字型名稱',
	'tabIndent': '標籤縮排',
	"fullScreen": "切換全螢幕",
	"viewSource": "檢視 HTML 原始檔",
	"print": "列印",
	"newPage": "新頁面",
	/* Error messages */
	'systemShortcut': '"${0}" 動作在您的瀏覽器中，只能使用鍵盤快速鍵。請使用 ${1}。'
})
//end v1.x content
);
